@@ -5,7 +5,7 @@ package MooseX::App::Plugin::ZshCompletion;
 
 use 5.010;
 
-our $VERSION = '0.001_001'; # VERSION
+our $VERSION = '0.002_001'; # TRIAL VERSION
 
 use namespace::autoclean;
 use Moose::Role;
@@ -48,19 +48,44 @@ In your base class:
  package MyApp;
  use MooseX::App qw/ ZshCompletion /;
 
-     .zshrc:
-     fpath=('completion-dir/zsh' $fpath)
+In your .zshrc:
+
+    fpath=('/path/to/completion-dir' $fpath)
 
 In your shell
 
- zsh% myapp zsh_completion > completion-dir/_myapp
- zsh% chmod u+x completion-dir/_myapp
+ zsh% myapp zsh_completion > /path/to/completion-dir/_myapp
+ zsh% chmod u+x /path/to/completion-dir/_myapp
  zsh% exec zsh
 
 =head1 DESCRIPTION
 
 This plugin generates a zsh completion definition for your application.
 
+Completion works for subcommands, parameters and options. If an option or
+parameter is declared as an C<enum> with L<Moose::Meta::TypeConstraint> you
+will get a completion for the enum values.
+
+Option completions will show its descriptions also.
+
+The default completion type for parameters is C<_files>
+
+In the examples directory you find C<moosex-app-zsh>.
+
+    % moosex-app-zsh <TAB>
+    bash_completion  fetch_mail    help          lala          zsh_completion
+
+    % moosex-app-zsh fetch_mail server.example -<TAB>
+    --dir                     -- Output 'dir'
+    --max                     -- Maximum number of emails to fetch
+    --servertype              -- Mailserver type: IMAP or POP3
+    --usage       --help  -h  -- Prints this usage information.
+    --user                    -- User
+    --verbose                 -- be verbose
+
+    % moosex-app-zsh fetch_mail server.example --servertype <TAB>
+    IMAP  POP3
+
 =head1 METHODS
 
 =over 4
