@@ -3,7 +3,7 @@ package MooseX::App::Plugin::ZshCompletion::Command;
 
 use Moose;
 use 5.010;
-our $VERSION = '0.001_001'; # VERSION
+our $VERSION = '0.002_001'; # TRIAL VERSION
 
 use namespace::autoclean;
 use MooseX::App::Command;
@@ -131,8 +131,6 @@ EOM
 
 # Built with $package on $year/$mon/$mday
 
-${prefix}_COMMANDS='help $command_list'
-
 _$prefix() {
     typeset -A opt_args
     local curcontext="\$curcontext" state line context
